# package_name

`rocket` is a Python library for going to space without root

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install `rocket`.

```bash
pip install rocket
```

## Usage

```python
import rocket

# returns distance between two rockets
rocket.get_distance(<another Rocket Object>)

# returns moves the rocket in the y axis
package_name.move_rocket( y= 10)



```

## License
[MIT](https://choosealicense.com/licenses/mit/)